==> Xew-3.1.tar.gz: Xew-3.1/Xew/Video.h <==
#ifndef _XewVideo_h
#define _XewVideo_h
/*
** Copyright 1992 by Markku Savela and
**	Technical Research Centre of Finland
*/


#include <X11/Xmu/Converters.h>

/* Parameters:

 Name		     Class		RepType		Default Value
 ----		     -----		-------		-------------
 background	     Background		Pixel		XtDefaultBackground
 border		     BorderColor	Pixel		XtDefaultForeground
 borderWidth	     BorderWidth	Dimension	0
 colormapInstall     ColormapInstall    Boolean         False
 colorMode           ColorMode          XeColorMode     XeColorMode_COLOR
 colorQuantize       ColorQuantize      XeColorQuantize XeColorQuantize_FAST
 contentFile         ContentFile        String          NULL
 contentLength       ContentLength      long            0
 contentOffset       ContentOffset      long            0
 contentStream       ContentStream      FILE *          NULL
 contentString       ContentString      Pointer         NULL
 currentFrame        CurrentFrame       long            1
 cursor              Cursor             Cursor          None
 destroyCallback     Callback		Pointer		NULL
 dither              Dither             XeDither        XeDither_FS4
 firstFrame          FirstFrame         long            1
 height		     Height		Dimension	0
 lastFrame           LastFrame          long            0
 mappedWhenManaged   MappedWhenManaged	Boolean		True
 maxColors           MaxColors          int             65535
 minFrameDelay       MinFrameDelay      int             0
 mirrorImage         MirrorImage        Boolean         False
 play                Play               XePlay          XePlay_FORWARD
 rotation            Rotation           int             0
 useShm              UseShm             Boolean         False
 visual              Visual             Visual *        NULL
 width		     Width		Dimension	0
 x		     Position		Position	0
 y		     Position		Position	0

*/

/* New fields */
#define XtNminFrameDelay "minFrameDelay"
#define XtCMinFrameDelay "MinFrameDelay"

	
/* Class record constants */

extern WidgetClass xeVideoWidgetClass;

typedef struct _XeVideoClassRec *XeVideoWidgetClass;
typedef struct _XeVideoRec *XeVideoWidget;


#endif

==> Xew-4.0.tar.gz: Xew-4.0/Xew/Video.h <==
#ifndef _XewVideo_h
#define _XewVideo_h
/*
** Copyright 1992-1995 by Markku Savela and
**	Technical Research Centre of Finland
*/

#include <X11/Xew/Animation.h>

/* Parameters:

 Name		     Class		RepType		Default Value
 ----		     -----		-------		-------------
 background	     Background		Pixel		XtDefaultBackground
 border		     BorderColor	Pixel		XtDefaultForeground
 borderWidth	     BorderWidth	Dimension	0
 colormapInstall     ColormapInstall    Boolean         False
 colorMode           ColorMode          XeColorMode     XeColorMode_COLOR
 colorQuantize       ColorQuantize      XeColorQuantize XeColorQuantize_FAST
 contentFile         ContentFile        String          NULL
 contentLength       ContentLength      long            0
 contentOffset       ContentOffset      long            0
 contentStream       ContentStream      FILE *          NULL
 contentString       ContentString      Pointer         NULL
 currentFrame        CurrentFrame       long            1
 cursor              Cursor             Cursor          None
 destroyCallback     Callback		Pointer		NULL
 dither              Dither             XeDither        XeDither_FS4
 firstFrame          FirstFrame         long            1
 height		     Height		Dimension	0
 lastFrame           LastFrame          long            0
 mappedWhenManaged   MappedWhenManaged	Boolean		True
 maxColors           MaxColors          int             65535
 minFrameDelay       MinFrameDelay      int             0
 mirrorImage         MirrorImage        Boolean         False
 play                Play               XePlay          XePlay_FORWARD
 rotation            Rotation           int             0
 useShm              UseShm             Boolean         False
 visual              Visual             Visual *        NULL
 width		     Width		Dimension	0
 x		     Position		Position	0
 y		     Position		Position	0

*/

/* New fields */
#define XtNminFrameDelay "minFrameDelay"
#define XtCMinFrameDelay "MinFrameDelay"

	
/* Class record constants */

extern WidgetClass xeVideoWidgetClass;

typedef struct _XeVideoClassRec *XeVideoWidgetClass;
typedef struct _XeVideoRec *XeVideoWidget;


#endif
